@@ -21,8 +21,8 @@ import org.eclipse.osgi.tests.services.resolver.AbstractStateTest;
 import org.osgi.framework.BundleException;
 
 
-public class TestRFC79_005 extends AbstractStateTest {
-	public TestRFC79_005(String testName) {
+public class TestRFC79_001 extends AbstractStateTest {
+	public TestRFC79_001(String testName) {
 		super(testName);
 	}
 
@@ -31,7 +31,7 @@ public class TestRFC79_005 extends AbstractStateTest {
 	BundleDescription bundle_3 = null;
 
 	
-	public void testTest_005() {
+	public void testTest_001() {
 		State state = buildEmptyState();
 		StateObjectFactory sof = StateObjectFactory.defaultFactory;
 
@@ -85,8 +85,19 @@ public class TestRFC79_005 extends AbstractStateTest {
 	} // end method
 
 	public void checkWiringState_3() {
+		ExportPackageDescription[] exports = bundle_3.getResolvedImports();
+		assertNotNull("export array is unexpectedly null", exports);
+		assertTrue("export array is unexpectedly empty", exports.length > 0);
+		for (int i = 0; i < exports.length; i++) {
+			String exportPackageName = exports[i].getName();
+			assertNotNull("package name is null", exportPackageName);
+			if (exportPackageName.equals("javax.servlet")) {
+				assertNotNull("Package [javax.servlet] is not wired when it should be ", exports[i].getExporter());
+				assertEquals("Package [javax.servlet] is wired incorrectly ", exports[i].getExporter(), bundle_2);
+			}
+		} // end for
 	} // end method
-	
+
 
 	public void checkWiring_a() {
 		checkWiringState_1();
@@ -109,7 +120,7 @@ public class TestRFC79_005 extends AbstractStateTest {
 	public void checkBundlesResolved_a() {
 		assertTrue("unexpected bundle resolution state", bundle_1.isResolved());
 		assertTrue("unexpected bundle resolution state", bundle_2.isResolved());
-		assertTrue("unexpected bundle resolution state", !bundle_3.isResolved());
+		assertTrue("unexpected bundle resolution state", bundle_3.isResolved());
 	} // end method
 
 	
@@ -148,7 +159,7 @@ public class TestRFC79_005 extends AbstractStateTest {
 		BundleDescription bundle = null;
 		dictionary_3.put("Bundle-ManifestVersion", "2");
 		dictionary_3.put("Bundle-SymbolicName", "C");
-		dictionary_3.put("Import-Package", "javax.servlet; version=\"[2.1.0, 2.1.0]\"");
+		dictionary_3.put("Import-Package", "javax.servlet; version=2.1.0");
 		try {
 			bundle = sof.createBundleDescription(dictionary_3, "bundle_3", 3);
 		} catch (BundleException be) {
@@ -157,4 +168,32 @@ public class TestRFC79_005 extends AbstractStateTest {
 		return bundle;
 	} // end of method
 
+	public BundleDescription create_bundle_4(StateObjectFactory sof) {
+		java.util.Dictionary dictionary_4 = new java.util.Properties();
+		BundleDescription bundle = null;
+		dictionary_4.put("Bundle-ManifestVersion", "2");
+		dictionary_4.put("Bundle-SymbolicName", "D");
+		dictionary_4.put("Import-Package", "foo; version=1.0; c=z");
+		try {
+			bundle = sof.createBundleDescription(dictionary_4, "bundle_4", 4);
+		} catch (BundleException be) {
+			fail(be.getMessage());
+		}
+		return bundle;
+	} // end of method
+
+	public BundleDescription create_bundle_5(StateObjectFactory sof) {
+		java.util.Dictionary dictionary_5 = new java.util.Properties();
+		BundleDescription bundle = null;
+		dictionary_5.put("Bundle-ManifestVersion", "2");
+		dictionary_5.put("Bundle-SymbolicName", "E");
+		dictionary_5.put("Import-Package", "foo; version=1.0; a=y");
+		try {
+			bundle = sof.createBundleDescription(dictionary_5, "bundle_5", 5);
+		} catch (BundleException be) {
+			fail(be.getMessage());
+		}
+		return bundle;
+	} // end of method
+
 } // end of testcase
